/* --------------------------------------------------------------------------------------
 *  Copyright (C) 2004 Dallas Semiconductor Corporation, All Rights Reserved.
 * 
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 * 
 *  The above copyright notice and this permission notice shall be included
 *  in all copies or substantial portions of the Software.
 * 
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
 *  OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *  MERCHANTABILITY,  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.
 *  IN NO EVENT SHALL DALLAS SEMICONDUCTOR BE LIABLE FOR ANY CLAIM, DAMAGES
 *  OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,
 *  ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR
 *  OTHER DEALINGS IN THE SOFTWARE.
 * 
 *  Except as contained in this notice, the name of Dallas Semiconductor
 *  shall not be used except as stated in the Dallas Semiconductor
 *  Branding Policy.
 *
 * --------------------------------------------------------------------------------------
 */
#include <iomaxq200x.h>
#include <intrinsics.h>

/* 
 * Compatible with the MAXQ2000 EVKit Rev. B
 */
#define LCD0_PATTERN_C    0x039
#define LCD0_PATTERN_F    0x071

#define LCD_PATTERN_0     0x03F
#define LCD_PATTERN_1     0x006
#define LCD_PATTERN_2     0x05B
#define LCD_PATTERN_3     0x04F
#define LCD_PATTERN_4     0x066
#define LCD_PATTERN_5     0x06D
#define LCD_PATTERN_6     0x07D
#define LCD_PATTERN_7     0x007
#define LCD_PATTERN_8     0x07F
#define LCD_PATTERN_9     0x067

int PATTERNS[] = { LCD_PATTERN_0, LCD_PATTERN_1, LCD_PATTERN_2, LCD_PATTERN_3, LCD_PATTERN_4, 
                   LCD_PATTERN_5, LCD_PATTERN_6, LCD_PATTERN_7, LCD_PATTERN_8, LCD_PATTERN_9 };

/******************************************************************************
 * Lights up the solitary 'one' segment on our LCD panel.
 */
show100s()
{
  LCD4 = 0x40;
}

/******************************************************************************
 * Returns the value that will need to be placed in one of LCD0-LCD3 to display 
 * a digit 0-9.  No bounds checking is done here.  If you ask for a digit other
 * than 0-9, you will get a bogus display.
 */
int getLCDDigit(int digit)
{
    return PATTERNS[digit];
}

int show(int value)
{
   if (value >= 10000)
      LCD4 = 0x40;
   else
      LCD4 = 0;
   LCD3 = getLCDDigit((value / 1000) % 10);
   LCD2 = getLCDDigit((value / 100) % 10);
   LCD1 = getLCDDigit((value / 10) % 10);
   LCD0 = getLCDDigit((value) % 10);
   return 0;
}

void initLCD()
{
  //LCRA_bit.FRM = 7;   // Set up frame frequency.
  //LCRA_bit.LCCS = 1;  // Set clock source to HF/128.
  //LCRA_bit.DUTY = 0;  // Set up static duty cycle.
  //LCRA_bit.LRA = 0;   // Set R-adj to 0.
  //LCRA_bit.LRIGC = 1; // Select external LCD drive power.
  LCRA = 0x03E0;        // Just do them all at once...

  LCFG_bit.PCF = 0x0F;// Set up all segments as outputs.
  LCFG_bit.OPM = 1;   // Set to normal operation mode.
  LCFG_bit.DPE = 1;   // Enable display.
}

/******************************************************************************
 * Main application entry point.  Initialize the serial port, timer, SPI/1407,
 * LCD, and external interrupts.  Then just do nothing.  The interrupts will
 * take care of everything else.
 */
void main()
{
  int counter = 0;
  int i=0;
  __enable_interrupt();
  initLCD();
  
  while(1)
  {
      for (i=0;i<0x1000;i++)
      {
         // just a delay loop
      }
      
      show(counter);
      if (counter>=19999)
          counter = 0;
      counter++;
  }
}

